@@ -6,7 +6,7 @@ test_that("Check elements can be retrieved", {
   expect_that(domain(url), equals("www.google.com"))
   expect_that(port(url), equals("80"))
   expect_that(path(url), equals("foo.php"))
-  expect_that(query(url), equals("api_params=turnip"))
+  expect_that(parameters(url), equals("api_params=turnip"))
   expect_that(fragment(url), equals("ending"))
 })
 
@@ -20,8 +20,8 @@ test_that("Check elements can be set", {
   expect_that(port(url), equals("23"))
   path(url) <- "bar.php"
   expect_that(path(url), equals("bar.php"))
-  query(url) <- "api_params=manic"
-  expect_that(query(url), equals("api_params=manic"))
+  parameters(url) <- "api_params=manic"
+  expect_that(parameters(url), equals("api_params=manic"))
   fragment(url) <- "beginning"
   expect_that(fragment(url), equals("beginning"))
 })
